@@ -8,16 +8,17 @@ from io import BytesIO
 from collections import OrderedDict
 
 try:
+    #makoがなくても動作するようにする
     from mako.lookup import TemplateLookup
-except:pass
+except ImportError:
+    pass
 
 try:
+    #sqlalchemyがなくても動作するようにする
     from sqlalchemy import Integer
-except:pass
-
-try:
     from rita.validator import Validator
-except:pass
+except ImportError:
+    pass
 from rita.session import HttpSession
 
 STATUS_CODES = {200:"OK", 206:"Partial Content"
@@ -31,13 +32,14 @@ STATUS_CODES = {200:"OK", 206:"Partial Content"
                 , 503:"Service Unavailable"}
 
 class _FinishResponseException(Exception):
+    """後に続く処理をせずにレスポンスを出力するときに投げる例外"""
     pass
 
 class BaseController(object):
     def __init__(self):
         self.env = {}
         self.attr = {"page":self}
-        self.charset = self.getCharSet()
+        self.charset = self.get_charset()
         self.outputExpiredHeader = True
 
         self._headers = {}
@@ -45,71 +47,9 @@ class BaseController(object):
         self._params = None
         self._fieldstorage = None
         self._output_buffer = BytesIO()
-    
-    def output(self, s):
-        self._output_buffer.write(s.encode(self.charset))
 
-    def status(self, code):
-        self._status = code
-        
-    def header(self, name, value=None):
-        #FIXME: nameはXxxx-Xxxxの形式に変換して統一すべきでは
-
-        #valueが指定されていなければ現在の値を返す
-        if value == None:
-            if name in self._headers:
-                return self._headers[name]
-            else:
-                return None
-        
-        #FIXME:正規表現でのホワイトリストチェックに変更
-        if value.find("\r") != -1 or value.find("\n") != -1:
-            raise ValueError("HTTP header must not contain control codes.")
-        
-        self._headers[name] = value       
-
-    def redirect(self, location, finish_response=True, permit_external_site=False):
-        """リダイレクトヘッダを出力する,finish_response=Trueならそれ以降の処理はしない
-        (str,bool,bool) as void"""
-        self.status(302)
-        self.header("Location", location)
-        if not permit_external_site:
-            if len(location) > 2: #/から始まるURL以外のサイトにリダイレクトさせない
-                #FIXME route.pyなどからのホワイトリスト対応の方がいいかも
-                if not(location.startswith("/") and location[1] != "/"):
-                    raise ValueError("redirect to external site is not permitted.")
-        
-        if finish_response:
-            self.finishResponse()
-
-    def finishResponse(self):
-        raise _FinishResponseException()
-
-    def FieldStorage(self):
-        if self._fieldstorage != None:
-            return self._fieldstorage
-
-        ret = {}
-        e = self.env.copy()
-        
-        if "CONTENT_TYPE" in e and e["CONTENT_TYPE"] == "application/json":
-            ret = json.loads(self.env['wsgi.input'].read().decode(self.charset))
-            if sys.version_info.major >= 3:
-                ret = dict([(k, cgi.MiniFieldStorage(k, str(v))) for k, v in ret.items()])
-            else:
-                ret = dict([(k, cgi.MiniFieldStorage(k, str(v) if not isinstance(v, unicode) else v.encode(self.charset))) for k, v in ret.items()])
-        else:
-            if sys.version_info.major >= 3:
-                ret = cgi.FieldStorage(fp=self.env['wsgi.input'], environ=e, keep_blank_values=1, encoding=self.charset)
-            else:
-                ret = cgi.FieldStorage(fp=self.env['wsgi.input'], environ=e, keep_blank_values=1)
-            if ret.value == "":
-                ret = {}
-            
-        self._fieldstorage = ret
-        return ret
-    
     def application(self, env, start_response):
+        """WSGIアプリケーションの本体。基本的にはオーバーライドはしない前提"""
         try:
             self.env = env
             self._initialize()
@@ -138,68 +78,105 @@ class BaseController(object):
         ret = self._output_buffer.getvalue()
         self._output_buffer.close()
         return [ret]
-
-    def _py2_i18n_helper(self, s):
-        #python2系だとバイト型の文字列が渡される場合があるため
-        if not isinstance(s, unicode):
-            s = s.decode("utf8")  
-        return gettext.Catalog("messages", self.getLocaleDir(), self.getLanguages(), fallback=True).gettext(s)
     
-    def _initialize(self):
-        self._params = self.FieldStorage()
-        self.session = self.getHttpSession()
-        self.currentUser = self.getCurrentUser()
-        locale_dir = self.getLocaleDir()
-        if locale_dir != None:
-            if sys.version_info.major >= 3:
-                self.attr["_"] = gettext.Catalog("messages", locale_dir, self.getLanguages(), fallback=True).gettext
-            else:
-                self.attr["_"] = self._py2_i18n_helper
-        else:
-            self.attr["_"] = lambda x:x
-
-    def getLocaleDir(self):
-        #国際化するならロケールデータが入ったディレクトリを返す
+    #begin:各アプリケーション側でオーバーライドするメソッド
+    def initialize(self):
+        """初期化や前処理を行う"""
+        pass #
+    
+    def auth(self):
+        """認証と認可を行う"""
         pass
 
+    def process(self):
+        """メインの処理"""
+        pass
+    #end:各アプリケーション側でオーバーライドするメソッド
+
+    #begin:必要に応じて継承先でオーバーライドするメソッド
+    def get_current_user(self):
+        return None
+
+    def get_charset(self):
+        return "utf8"    
+
+    def get_locale_dir(self):
+        pass
+
+    def get_languages(self):
+        return ["ja-jp"]
+
+    def get_http_session(self):
+        return HttpSession(self)
+
+    def get_http_session_store(self):
+        return {}
+
     def finalize(self):
-        #必要あれば子クラスでオーバーライド
+        """終了処理。デフォルトではセッションストアから切断する"""
         try:
             self.session.close()
         except:pass
     
-    def getCharSet(self):
-        #必要あれば子クラスでオーバーライド
-        return "utf8"
-    
-    def getHttpSessionStore(self):
-        #必要あれば子クラスでオーバーライド
-        return {}
-    
-    def getHttpSession(self):
-        #必要あれば子クラスでオーバーライド
-        return HttpSession(self)
-
-    def getDocumentRoot(self):
-        #必要あれば子クラスでオーバーライド
+    def get_document_root(self):
         return "."
-    
-    def getCurrentUser(self):
-        return None
+    #end:必要に応じて継承先でオーバーライドするメソッド
 
-    def getLanguages(self):
-        return ["ja-jp"]
+    #begin:アプリケーションの実装において呼び出す想定のメソッド（オーバーライドはされない想定）
+    def output(self, s):
+        """出力バッファに文字列を直接出力する"""
+        self._output_buffer.write(s.encode(self.charset))
 
-    def initialize(self):
-        pass #アプリケーション側で必要に応じて実装する
-    
-    def auth(self):
-        pass #アプリケーション側で必要に応じて実装する
-    
-    def _preprocess(self):
-        pass #親クラスでは何もしない（フレームワーク内の継承先で必要に応じて実装する）
+    def status(self, code):
+        """ステータスコードを設定する"""
+        self._status = code
+        
+    def header(self, name, value=None):
+        """ヘッダーを出力する"""
+        #FIXME: nameはXxxx-Xxxxの形式に変換して統一すべきでは
 
-    def renderString(self, file_name=None):
+        #valueが指定されていなければ現在の値を返す
+        if value == None:
+            if name in self._headers:
+                return self._headers[name]
+            else:
+                return None
+        
+        #FIXME:正規表現でのホワイトリストチェックに変更
+        if value.find("\r") != -1 or value.find("\n") != -1:
+            raise ValueError("HTTP header must not contain control codes.")
+        
+        self._headers[name] = value       
+
+    def finish_response(self):
+        """リクエストの処理を終了する（残りの処理はしない）"""
+        raise _FinishResponseException()
+
+    def FieldStorage(self):
+        if self._fieldstorage != None:
+            return self._fieldstorage
+
+        ret = {}
+        e = self.env.copy()
+        
+        if "CONTENT_TYPE" in e and e["CONTENT_TYPE"] == "application/json":
+            ret = json.loads(self.env['wsgi.input'].read().decode(self.charset))
+            if sys.version_info.major >= 3:
+                ret = dict([(k, cgi.MiniFieldStorage(k, str(v))) for k, v in ret.items()])
+            else:
+                ret = dict([(k, cgi.MiniFieldStorage(k, str(v) if not isinstance(v, unicode) else v.encode(self.charset))) for k, v in ret.items()])
+        else:
+            if sys.version_info.major >= 3:
+                ret = cgi.FieldStorage(fp=self.env['wsgi.input'], environ=e, keep_blank_values=1, encoding=self.charset)
+            else:
+                ret = cgi.FieldStorage(fp=self.env['wsgi.input'], environ=e, keep_blank_values=1)
+            if ret.value == "":
+                ret = {}
+            
+        self._fieldstorage = ret
+        return ret
+
+    def render_string(self, file_name=None):
         """テンプレートから文字列を生成する"""
         #モジュール名を解析
         modile_name = self.__module__
@@ -212,19 +189,20 @@ class BaseController(object):
         #テンプレートファイルを探す
         mylookup = None
         if sys.version_info.major >= 3:
-            mylookup = TemplateLookup(directories=[self.getDocumentRoot() + folder], input_encoding="utf-8", default_filters=["h", "str"])
+            mylookup = TemplateLookup(directories=[self.get_document_root() + folder], input_encoding="utf-8", default_filters=["h", "str"])
         else:
             default_filters = ["decode." + self.charset] + ["h"]
-            mylookup = TemplateLookup(directories=[self.getDocumentRoot() + folder], input_encoding="utf-8", default_filters=default_filters)
+            mylookup = TemplateLookup(directories=[self.get_document_root() + folder], input_encoding="utf-8", default_filters=default_filters)
         mytemplate = mylookup.get_template(file_name)
 
         return mytemplate.render_unicode(**self.attr)
 
     def render(self, file_name=None):
-        """テンプレートから文字列を出力する"""
-        self.output(self.renderString(file_name))
+        """テンプレートから文字列を生成して出力バッファに出力する"""
+        self.output(self.render_string(file_name))
         
-    def getParam(self, name, default=None):
+    def get_param(self, name, default=None):
+        """パラメータを取得する"""
         if name in self._params:
             param = self._params[name]
             if isinstance(param, cgi.FieldStorage):
@@ -241,11 +219,47 @@ class BaseController(object):
                 return ret
         return default
 
+    def redirect(self, location, finish_response=True, permit_external_site=False):
+        """リダイレクトヘッダを出力する,finish_response=Trueならそれ以降の処理はしない"""
+        self.status(302)
+        self.header("Location", location)
+        if not permit_external_site:
+            if len(location) > 2: #/から始まるURL以外のサイトにリダイレクトさせない
+                #FIXME route.pyなどからのホワイトリスト対応の方がいいかも
+                if not(location.startswith("/") and location[1] != "/"):
+                    raise ValueError("redirect to external site is not permitted.")
+        
+        if finish_response:
+            self.finish_response()
+    #end:アプリケーションの実装において呼び出す想定のメソッド（オーバーライドはされない想定）
+    
+    #begin:private
+    def _initialize(self):
+        self._params = self.FieldStorage()
+        self.session = self.get_http_session()
+        self.currentUser = self.get_current_user()
+        locale_dir = self.get_locale_dir()
+        if locale_dir != None:
+            if sys.version_info.major >= 3:
+                self.attr["_"] = gettext.Catalog("messages", locale_dir, self.get_languages(), fallback=True).gettext
+            else:
+                self.attr["_"] = self._py2_i18n_helper
+        else:
+            self.attr["_"] = lambda x:x
+
+    def _py2_i18n_helper(self, s):
+        #python2系だとバイト型の文字列が渡される場合があるため
+        if not isinstance(s, unicode):
+            s = s.decode("utf8")  
+        return gettext.Catalog("messages", self.get_locale_dir(), self.get_languages(), fallback=True).gettext(s)
+
+    def _preprocess(self):
+        pass #親クラスでは何もしない（フレームワーク内の継承先で必要に応じて実装する）
+    #end:private
+
 class _FormInput(object):
     def __init__(self, value):
         self.value = value
-        #入力チェックが済んでいるかどうか
-        self.checked = False
         self.errors = []
 
 class FormState(object):
@@ -269,17 +283,64 @@ class BaseFormController(BaseController):
         self._cached_target = None
         self._validation_result = None #validateメソッドを呼び出した結果のキャッシュ
 
-    def _preprocess(self):
-        self.form = {}
-        for name in self.fields.keys():
-            self.form[name] = _FormInput(self.getParam(name, ""))
-        if not self.isPostBack():
-            self._prepareForm()
-            self.prepareForm()
+    #begin:各アプリケーション側でオーバーライドするメソッド
+    def validateForm(self):
+        return True
+    #end:各アプリケーション側でオーバーライドするメソッド
 
-    def getParam(self, name, default=None):
-        ret = BaseController.getParam(self, name, default)
+    #begin:必要に応じて継承先でオーバーライドするメソッド
+    def get_db_session(self):
+        """sqlalchemyのセッションを返す"""
+        return None
+
+    def get_primary_key(self):
+        """フォーム編集や削除時の主キーを取得する"""
+        splited = str(self.env["PATH_INFO"]).split("/")
+        try:
+            return int(splited[-1])
+        except:
+            return None
+
+    def prepare_form(self):
+        """DBからフォームの初期値を用意する"""
+        target = self.get_target()
+        if target != None:
+            for field_name in self.targetFieldNames:
+                self.form[field_name].value = getattr(target, field_name) 
+    #end:必要に応じて継承先でオーバーライドするメソッド
+    
+    #begin:アプリケーションの実装において呼び出す想定のメソッド（オーバーライドはされない想定）
+    def is_post_back(self):
+        return self.get_param("_POST_BACK") == "true"
+
+    def get_form_state(self):
+        #memo:結果をキャッシュした方がいいかも
+        action = self.get_param("_ACTION")
+        cancel_clicked = self.get_param("_CANCEL") != None
+        if self.get_param("__mode__") == "delete":
+            if cancel_clicked:
+                return FormState.CANCELED
+            if self.is_post_back() and self._validate_hidden_token() and action == "complete":
+                return FormState.DELETE_READY
+            else:
+                return FormState.DELETE_CONFIRM
+        else:
+            if self.is_post_back() and self._validate_hidden_token() and self._validate_form():
+                if self.showInputConfirm == False or action == "complete":
+                    if cancel_clicked:
+                        return FormState.INPUTTING
+                    else:
+                        return FormState.INPUT_READY
+                else:
+                    if cancel_clicked:
+                        return FormState.CANCELED
+                    else:
+                        return FormState.INPUT_CONFIRM
+        return FormState.INPUTTING
+
+    def get_param(self, name, default=None):
         #数値のフィールドの場合は全角数値は自動的に半角に変換する
+        ret = BaseController.get_param(self, name, default)
         if self.targetClass != None:
             if name in self.fields:
                 dbtype = self.targetClass.metadata.tables[self.targetClass.__tablename__].columns[name].type
@@ -296,45 +357,104 @@ class BaseFormController(BaseController):
                             pass
         return ret
 
-    def getDBSession(self):
-        return None
-    
-    def getPrimaryKey(self):
-        splited = str(self.env["PATH_INFO"]).split("/")
-        try:
-            return int(splited[-1])
-        except:
-            return None
-            
-    def getTargetWithSession(self):
-        session = self.getDBSession()
-        if self.targetClass != None:
-            if self.getPrimaryKey() != None:
-                return session, session.query(self.targetClass).filter(self.targetClass.id == int(self.getPrimaryKey()))[0]
-        return session, None
-    
-    def getTarget(self, use_cache=True):
+    def get_target(self, use_cache=True):
+        """編集や削除対象のモデルを取得する（新規作成の場合はNoneを返す）"""
         if use_cache and self._cached_target != None:
             return self._cached_target
-        session, ret = self.getTargetWithSession()
+        session, ret = self.get_target_with_session()
         self._cached_target = ret
         return ret
+
+    def get_target_with_session(self):
+        """編集や削除対象のモデルを、関連したDBのセッションと共に取得する"""
+        session = self.get_db_session()
+        if self.targetClass != None:
+            if self.get_primary_key() != None:
+                return session, session.query(self.targetClass).filter(self.targetClass.id == int(self.get_primary_key()))[0]
+        return session, None
+            
+    def update_target(self, options=None, auto_commit=True):
+        """フォーム内容に基づいてモデルを更新する"""
+        if options == None:options = {} 
+        session, target = self.get_target_with_session()
+        if target == None:
+            target = self.targetClass()
+            session.add(target)
+
+        for name in self.targetFieldNames:
+            value = self.form[name].value
+            setattr(target, name, value)
+                
+        for name in options:
+            setattr(target, name, options[name])
+        if auto_commit:
+            session.commit()
+        return target
+
+    def delete_target(self, auto_commit=True):
+        """モデルを削除する"""
+        session, target = self.get_target_with_session()
+        if target == None:
+            return
+        
+        session.delete(target)
+        if auto_commit:
+            session.commit()
+    #end:アプリケーションの実装において呼び出す想定のメソッド（オーバーライドはされない想定）
+
+    #begin:フォーム描画用メソッド
+    def render_form_begin(self):
+        return """<form method="POST">"""
     
-    def prepareForm(self):
-        target = self.getTarget()
-        if target != None:
-            for field_name in self.targetFieldNames:
-                self.form[field_name].value = getattr(target, field_name) 
+    def render_form_end(self):
+        ret = ["""<input type="hidden" name="_POST_BACK" value="true"/>"""]
+        if self.session.sessionid != None:
+            ret.append("""<input type="hidden" name="_rita_hidden_token" value="%s"/>""" % (self.session["_rita_hidden_token"]))
+
+        if self.get_form_state() == FormState.DELETE_CONFIRM or (self.showInputConfirm == False or self.get_form_state() == FormState.INPUT_CONFIRM):
+            ret.append("""<input type="hidden" name="_ACTION" value="complete"/>""")
+                            
+        ret.append("</form>")
+        return "\n".join(ret)
     
-    def _prepareForm(self):
-        pass
+    def render_label(self, name):
+        return self.fields[name].name
+
+    def render_input(self, name):
+        return self.fields[name].render(name, self.form[name].value, readonly=self.get_form_state() in [FormState.DELETE_CONFIRM, FormState.INPUT_CONFIRM])
+
+    def render_error(self, name):
+        return "<br/>".join(self.form[name].errors)
     
-    def _validateForm(self):
+    def render_submit(self):
+        if self.get_form_state() == FormState.DELETE_CONFIRM:
+            return """<input type="submit" value="削除">"""
+        elif self.showInputConfirm == False or self.get_form_state() == FormState.INPUT_CONFIRM:
+            return """<input type="submit" value="送信">"""
+        else:
+            return """<input type="submit" value="入力内容の確認">"""
+
+    def render_cancel(self):
+        value = self.attr["_"]("キャンセル")
+        if self.get_form_state() == FormState.INPUT_CONFIRM:
+            value = self.attr["_"]("入力画面に戻る")
+        return """<input type="submit" name="_CANCEL" value="%s">""" % (value)
+    #end:フォーム描画用メソッド
+
+    #begin:private
+    def _preprocess(self):
+        self.form = {}
+        for name in self.fields.keys():
+            self.form[name] = _FormInput(self.get_param(name, ""))
+        if not self.is_post_back():
+            self.prepare_form()
+
+    def _validate_form(self):
         #一度呼び出し済みなら結果のみを返す
         if self._validation_result != None:
             return self._validation_result
 
-        if not self.isPostBack():return
+        if not self.is_post_back():return
         ret = True
 
         all_error_messages = []
@@ -356,100 +476,7 @@ class BaseFormController(BaseController):
         self._validation_result = ret #バリデーション結果をキャッシュ
         return ret
 
-    def validateForm(self):
-        return True #子クラスで実装
-            
-    def updateTarget(self, options=None, auto_commit=True):
-        if options == None:options = {} 
-        session, target = self.getTargetWithSession()
-        if target == None:
-            target = self.targetClass()
-            session.add(target)
-
-        for name in self.targetFieldNames:
-            value = self.form[name].value
-            setattr(target, name, value)
-                
-        for name in options:
-            setattr(target, name, options[name])
-        if auto_commit:
-            session.commit()
-        return target
-
-    def deleteTarget(self, auto_commit=True):
-        session, target = self.getTargetWithSession()
-        if target == None:
-            return
-        
-        session.delete(target)
-        if auto_commit:
-            session.commit()
-
-    def isPostBack(self):
-        return self.getParam("_POST_BACK") == "true"
-
-    def _validateHiddenToken(self):
+    def _validate_hidden_token(self):
         #CSRF防止用トークンの検証、別メソッドにするのはテストフレームワーク側でオーバーライドするため
-        return not(self.session.sessionid != None and self.getParam("_rita_hidden_token") != self.session["_rita_hidden_token"])
-    
-    def getFormState(self):
-        #memo:結果をキャッシュした方がいいかも
-        action = self.getParam("_ACTION")
-        cancel_clicked = self.getParam("_CANCEL") != None
-        if self.getParam("__mode__") == "delete":
-            if cancel_clicked:
-                return FormState.CANCELED
-            if self.isPostBack() and self._validateHiddenToken() and action == "complete":
-                return FormState.DELETE_READY
-            else:
-                return FormState.DELETE_CONFIRM
-        else:
-            if self.isPostBack() and self._validateHiddenToken() and self._validateForm():
-                if self.showInputConfirm == False or action == "complete":
-                    if cancel_clicked:
-                        return FormState.INPUTTING
-                    else:
-                        return FormState.INPUT_READY
-                else:
-                    if cancel_clicked:
-                        return FormState.CANCELED
-                    else:
-                        return FormState.INPUT_CONFIRM
-        return FormState.INPUTTING
-
-    def renderFormBegin(self):
-        return """<form method="POST">"""
-    
-    def renderFormEnd(self):
-        ret = ["""<input type="hidden" name="_POST_BACK" value="true"/>"""]
-        if self.session.sessionid != None:
-            ret.append("""<input type="hidden" name="_rita_hidden_token" value="%s"/>""" % (self.session["_rita_hidden_token"]))
-
-        if self.getFormState() == FormState.DELETE_CONFIRM or (self.showInputConfirm == False or self.getFormState() == FormState.INPUT_CONFIRM):
-            ret.append("""<input type="hidden" name="_ACTION" value="complete"/>""")
-                            
-        ret.append("</form>")
-        return "\n".join(ret)
-    
-    def renderLabel(self, name):
-        return self.fields[name].name
-
-    def renderInput(self, name):
-        return self.fields[name].render(name, self.form[name].value, readonly=self.getFormState() in [FormState.DELETE_CONFIRM, FormState.INPUT_CONFIRM])
-
-    def renderError(self, name):
-        return "<br/>".join(self.form[name].errors)
-    
-    def renderSubmit(self):
-        if self.getFormState() == FormState.DELETE_CONFIRM:
-            return """<input type="submit" value="削除">"""
-        elif self.showInputConfirm == False or self.getFormState() == FormState.INPUT_CONFIRM:
-            return """<input type="submit" value="送信">"""
-        else:
-            return """<input type="submit" value="入力内容の確認">"""
-
-    def renderCancel(self):
-        value = self.attr["_"]("キャンセル")
-        if self.getFormState() == FormState.INPUT_CONFIRM:
-            value = self.attr["_"]("入力画面に戻る")
-        return """<input type="submit" name="_CANCEL" value="%s">""" % (value)
+        return not(self.session.sessionid != None and self.get_param("_rita_hidden_token") != self.session["_rita_hidden_token"])
+    #end:private
