@@ -8,7 +8,7 @@ class Field:
             validators = []
         self.validators = validators
         
-    def htmlEscape(self, s):
+    def html_escape(self, s):
         if s == None or not isinstance(s, str):
             return s
         return cgi.escape(s, True).replace("'", "&#39;")
@@ -19,9 +19,9 @@ class TextField(Field):
     
     def render(self, name, value, readonly=False, opt=None):
         if readonly:
-            return """%(value)s<input type="hidden" name="%(name)s" value="%(value)s"/>""" % {"name":name, "value":self.htmlEscape(value)}
+            return """%(value)s<input type="hidden" name="%(name)s" value="%(value)s"/>""" % {"name":name, "value":self.html_escape(value)}
         else:
-            return """<input type="text" id="c_%(name)s" name="%(name)s" value="%(value)s"/>""" % {"name":name, "value":self.htmlEscape(value)}
+            return """<input type="text" id="c_%(name)s" name="%(name)s" value="%(value)s"/>""" % {"name":name, "value":self.html_escape(value)}
 
 class TextAreaField(Field):
     def __init__(self, name, validators=None):
@@ -29,6 +29,8 @@ class TextAreaField(Field):
 
     def render(self, name, value, readonly=False, opt=None):
         if readonly:
-            return """%(display_value)s<input type="hidden" name="%(name)s" value="%(value)s"/>""" % {"display_value":self.htmlEscape(value).replace("\n", "<br/>"), "name":name, "value":self.htmlEscape(value)}
+            return """%(display_value)s<input type="hidden" name="%(name)s" value="%(value)s"/>""" % {"display_value":self.html_escape(value).replace("\n", "<br/>"), "name":name, "value":self.html_escape(value)}
         else:
-            return """<textarea id="c_%(name)s" name="%(name)s">%(value)s</textarea>""" % {"name":name, "value":self.htmlEscape(value)}
+            return """<textarea id="c_%(name)s" name="%(name)s">%(value)s</textarea>""" % {"name":name, "value":self.html_escape(value)}
+
+#TODO: DropDownListField,CheckBoxField,RadioButtonField,DateField,DateTimeField
